@@ -26,8 +26,8 @@
 #include <unistd.h>
 #include <iostream>
 #include <gtkmm/window.h>
-#include <libglademm.h>
 #include <glib/gi18n.h>
+#include "nmv-str-utils.h"
 #include "nmv-exception.h"
 #include "nmv-initializer.h"
 #include "nmv-i-workbench.h"
@@ -44,6 +44,7 @@ using nemiver::IWorkbench;
 using nemiver::IWorkbenchSafePtr;
 using nemiver::IDBGPerspective;
 using nemiver::common::UString;
+using nemiver::common::GCharSafePtr;
 using nemiver::ISessMgr;
 
 static const UString DBGPERSPECTIVE_PLUGIN_NAME="dbgperspective";
@@ -54,9 +55,11 @@ static bool gv_purge_sessions=false;
 static int gv_execute_session=0;
 static bool gv_last_session=false;
 static gchar *gv_log_domains=0;
-static bool gv_log_debugger_output=false;
-static bool gv_show_version=false;
-static bool gv_use_launch_terminal=false;
+static bool gv_log_debugger_output = false;
+static bool gv_show_version = false;
+static bool gv_use_launch_terminal = false;
+static gchar *gv_remote = 0;
+static gchar *gv_solib_prefix = 0;
 
 static GOptionEntry entries[] =
 {
@@ -67,7 +70,7 @@ static GOptionEntry entries[] =
       G_OPTION_ARG_STRING,
       &gv_env_vars,
       _("Set the environment of the program to debug"),
-      "\"var0=val0 var1=val1 var2=val2 ...\""
+      "<\"var0=val0 var1=val1 var2=val2 ...\">"
     },
     {
       "attach",
@@ -100,7 +103,7 @@ static GOptionEntry entries[] =
       G_OPTION_ARG_INT,
       &gv_execute_session,
       _("Debug the program that was of session number N"),
-      "N"
+      "<N>"
     },
     { "last",
       0,
@@ -116,7 +119,7 @@ static GOptionEntry entries[] =
       G_OPTION_ARG_STRING,
       &gv_log_domains,
       _("Enable logging domains DOMAINS"),
-      "DOMAINS"
+      "<DOMAINS>"
     },
     { "log-debugger-output",
       0,
@@ -134,6 +137,25 @@ static GOptionEntry entries[] =
       _("Use this terminal as the debugee's terminal"),
       NULL
     },
+    {
+      "remote",
+      0,
+      0,
+      G_OPTION_ARG_STRING,
+      &gv_remote,
+      _("Connect to remote target specified by HOST:PORT"),
+      "<HOST:PORT|serial-line-path>"
+    },
+    {
+      "solib-prefix",
+      0,
+      0,
+      G_OPTION_ARG_STRING,
+      &gv_solib_prefix,
+      _("Where to look for shared libraries loaded by the inferior. "
+	"Use in conjunction with --remote"),
+      "</path/to/prefix>"
+    },
     { "version",
       0,
       0,
@@ -142,7 +164,7 @@ static GOptionEntry entries[] =
       _("Show the version number of nemiver"),
       NULL
     },
-    {0,0,0,(GOptionArg)0,0,0,0}
+    {0, 0, 0, (GOptionArg) 0, 0, 0, 0}
 };
 
 struct GOptionContextUnref {
@@ -217,13 +239,24 @@ init_option_context ()
     g_option_context_set_ignore_unknown_options (context.get (), false);
     GOptionGroupSafePtr gtk_option_group (gtk_get_option_group (FALSE));
     THROW_IF_FAIL (gtk_option_group);
-    g_option_context_add_group (context.get (), gtk_option_group.release ());
+    g_option_context_add_group (context.get (),
+                                gtk_option_group.release ());
     return context.release ();
 }
 
-// Parse the command line and edits it
-// to make it contain the command line of the inferior program.
-static void
+/// Parse the command line and edits it
+/// to make it contain the command line of the inferior program.
+/// If an error happens (e.g, the user provided the wrong command
+/// lines) then display an usage help message and return
+/// false. Otherwise, return true.
+/// \param a_arg the argument count. This is the length of a_argv.
+///  This is going to be edited. After edit, only the number of
+///  arguments of the inferior will be put in this variable.
+/// \param a_argv the string of arguments passed to Nemiver. This is
+/// going to be edited so that only the arguments passed to the
+/// inferior will be left in this.
+/// \return true upon successful completion, false otherwise. If the
+static bool
 parse_command_line (int& a_argc,
                     char** a_argv)
 {
@@ -234,7 +267,7 @@ parse_command_line (int& a_argc,
         // We have no inferior program so edit the command like accordingly.
         a_argc = 0;
         a_argv[0] = 0;
-        return;
+        return true;
     }
 
     // Split the command like in two parts. One part is made of the options
@@ -260,13 +293,55 @@ parse_command_line (int& a_argc,
     }
     nmv_argv = a_argv;
     inf_argv = a_argv + i;
-    g_option_context_parse (context.get (), &nmv_argc, &nmv_argv, 0);
+    GError *error = NULL;
+    if (g_option_context_parse (context.get (),
+                                &nmv_argc,
+                                &nmv_argv,
+                                &error) != TRUE) {
+        NEMIVER_TRY;
+        if (error)
+            cerr << "error: "<< error->message << std::endl;
+        NEMIVER_CATCH;
+        g_error_free (error);
+
+        GCharSafePtr help_message;
+        help_message.reset (g_option_context_get_help (context.get (),
+                                                       true, NULL));
+        cerr << help_message.get () << std::endl;
+        return false;
+    }
+
     if (a_argv != inf_argv) {
         memmove (a_argv, inf_argv, inf_argc * sizeof (char*));
         a_argc = inf_argc;
     }
+
+    //***************************************************************
+    // Here goes some sanity checking on the command line parsed so far.
+    //****************************************************************
+
+    // If the user wants to debug a binary running on a remote target,
+    // make sure she provides us with a local copy of the binary too.
+    if (gv_remote) {
+        if (a_argc < 1 || a_argv[0][0] == '-') {
+            cerr << _("Please provide a local copy of the binary "
+                      "you intend to debug remotely.\n"
+                      "Like this:\n")
+                 << "nemiver --remote=" << gv_remote
+                 << " <binary-copy>\n\n";
+            cerr << _("Otherwise, find below the full set of nemiver options.\n");
+            GCharSafePtr help_message;
+            help_message.reset (g_option_context_get_help (context.get (),
+                                                           true, NULL));
+            cerr << help_message.get () << std::endl;
+            return false;
+        }
+    }
+    return true;
 }
 
+// Return true if Nemiver should keep going after the non gui options
+// have been processed.
 static bool
 process_non_gui_options ()
 {
@@ -291,6 +366,8 @@ process_non_gui_options ()
     return true;
 }
 
+/// Return true if Nemiver should keep going after the GUI option(s)
+/// have been processed.
 static bool
 process_gui_options (int& a_argc, char** a_argv)
 {
@@ -470,7 +547,31 @@ process_gui_options (int& a_argc, char** a_argv)
                 env[name] = value;
             }
         }
-        if (!prog_path.empty ()) {
+	if (gv_remote) {
+            // The user asked to connect to a remote target.
+            std::string host;
+            unsigned port = 0;
+            std::string solib_prefix;
+
+            if (gv_solib_prefix)
+                solib_prefix = gv_solib_prefix;
+
+            if (nemiver::str_utils::parse_host_and_port (gv_remote,
+                                                         host, port)) {
+                // So it looks like gv_remote has the form
+                // "host:port", so let's try to connect to that.
+                debug_persp->connect_to_remote_target (host, port,
+                                                       prog_path,
+                                                       solib_prefix);
+            } else {
+                // We think gv_remote contains a serial line address.
+                // Let's try to connect via the serial line then.
+                debug_persp->connect_to_remote_target (gv_remote,
+                                                       prog_path,
+                                                       solib_prefix);
+            }
+	} else if (!prog_path.empty ()) {
+            // The user wants to debug a local program
             debug_persp->uses_launch_terminal (gv_use_launch_terminal);
             debug_persp->execute_program (prog_path,
                                           prog_args,
@@ -495,7 +596,8 @@ main (int a_argc, char *a_argv[])
     Initializer::do_init ();
     Gtk::Main gtk_kit (a_argc, a_argv);
 
-    parse_command_line (a_argc, a_argv);
+    if (parse_command_line (a_argc, a_argv) == false)
+        return -1;
 
     if (process_non_gui_options () != true) {
         return -1;
