@@ -39,8 +39,8 @@
 #include "nmv-debugger-utils.h"
 
 using namespace nemiver::common;
-namespace vutil=nemiver::variables_utils2;
-namespace dutil=nemiver::debugger_utils;
+namespace vutil = nemiver::variables_utils2;
+namespace dutil = nemiver::debugger_utils;
 using Glib::RefPtr;
 
 NEMIVER_BEGIN_NAMESPACE (nemiver)
@@ -365,7 +365,8 @@ public:
             vutil::append_a_variable (a_var,
                                       *tree_view,
                                       tree_store,
-                                      parent_row_it);
+                                      parent_row_it,
+                                      false /* do not truncate types */);
             tree_view->expand_row (tree_store->get_path (parent_row_it), false);
             local_vars.push_back (a_var);
         }
@@ -383,14 +384,16 @@ public:
             vutil::append_a_variable (a_var,
                                       *tree_view,
                                       tree_store,
-                                      parent_row_it);
+                                      parent_row_it,
+                                      false /* do not truncate type */);
             tree_view->expand_row (tree_store->get_path (parent_row_it), false);
             function_arguments.push_back (a_var);
         }
     }
 
     void
-    update_a_local_variable (const IDebugger::VariableSafePtr a_var)
+    update_a_local_variable (const IDebugger::VariableSafePtr a_var,
+                             bool a_update_members = true)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
 
@@ -400,8 +403,10 @@ public:
         if (get_local_variables_row_iterator (parent_row_it)) {
             vutil::update_a_variable (a_var, *tree_view,
                                       parent_row_it,
+                                      false /* do not truncate type */,
                                       true /* handle highlight */,
-                                      false /* is not a new frame */);
+                                      false /* is not a new frame */,
+                                      a_update_members);
         }
     }
 
@@ -418,6 +423,7 @@ public:
             return vutil::update_a_variable (a_var,
                                              *tree_view,
                                              parent_row_it,
+                                             false /* do not truncate type */,
                                              true /* handle highlight */,
                                              false /* is not a new frame */);
         }
@@ -743,7 +749,16 @@ public:
         for (IDebugger::VariableList::const_iterator it = a_vars.begin ();
              it != a_vars.end ();
              ++it) {
-            update_a_local_variable (*it);
+            // Update the local variable pointed to by it.
+            // Note that we shall not recursively update the members of the
+            // the *it variable (in case it has members variables itself)
+            // because each member variable that needs updating is passed as
+            // part of a_vars - and as a result will be updated
+            // separately by a call to update_a_local_variable.
+            // At least that's the current behaviour with the "GDB/MI
+            // Variable Objects" based backend we are using.
+            update_a_local_variable (*it,
+                                     false /* do not update members */);
             local_vars_changed_at_prev_stop.push_back (*it);
         }
 
@@ -839,7 +854,8 @@ public:
         vutil::update_unfolded_variable (a_var,
                                          *tree_view,
                                          tree_store,
-                                         var_it);
+                                         var_it,
+                                         false /* do not truncate type */);
         tree_view->expand_row (a_var_node, false);
         NEMIVER_CATCH
     }
@@ -1025,7 +1041,10 @@ public:
         THROW_IF_FAIL (var_row);
         THROW_IF_FAIL (tree_view);
         vutil::update_a_variable_node (a_var, *tree_view,
-                                       var_row, false, false);
+                                       var_row,
+                                       false /* do not truncate type */,
+                                       false /* do not highlight variable */,
+                                       false /* frame ain't new */);
 
         NEMIVER_CATCH
     }
