@@ -42,26 +42,26 @@
 #include "nmv-i-perspective.h"
 #include "nmv-i-conf-mgr.h"
 
-using namespace std ;
-using namespace nemiver ;
-using namespace nemiver::common ;
+using namespace std;
+using namespace nemiver;
+using namespace nemiver::common;
 
 NEMIVER_BEGIN_NAMESPACE (nemiver)
 
 static const UString CONF_KEY_NEMIVER_WINDOW_WIDTH =
-                "/apps/nemiver/workbench/window-width" ;
+                "/apps/nemiver/workbench/window-width";
 static const UString CONF_KEY_NEMIVER_WINDOW_HEIGHT =
-                "/apps/nemiver/workbench/window-height" ;
+                "/apps/nemiver/workbench/window-height";
 static const UString CONF_KEY_NEMIVER_WINDOW_POSITION_X =
-                "/apps/nemiver/workbench/window-position-x" ;
+                "/apps/nemiver/workbench/window-position-x";
 static const UString CONF_KEY_NEMIVER_WINDOW_POSITION_Y =
-                "/apps/nemiver/workbench/window-position-y" ;
+                "/apps/nemiver/workbench/window-position-y";
 static const UString CONF_KEY_NEMIVER_WINDOW_MAXIMIZED =
-                "/apps/nemiver/workbench/window-maximized" ;
+                "/apps/nemiver/workbench/window-maximized";
 static const UString CONF_KEY_NEMIVER_WINDOW_MINIMUM_WIDTH=
-                "/apps/nemiver/workbench/window-minimum-width" ;
+                "/apps/nemiver/workbench/window-minimum-width";
 static const UString CONF_KEY_NEMIVER_WINDOW_MINIMUM_HEIGHT=
-                "/apps/nemiver/workbench/window-minimum-height" ;
+                "/apps/nemiver/workbench/window-minimum-height";
 
 
 class WorkbenchStaticInit {
@@ -70,31 +70,31 @@ class WorkbenchStaticInit {
 #ifdef WITH_GIO
         Gio::init();
 #else
-        gnome_vfs_init () ;
+        gnome_vfs_init ();
 #endif // WITH_GIO
     }
 
     ~WorkbenchStaticInit ()
     {
 #ifndef WITH_GIO
-        gnome_vfs_shutdown () ;
+        gnome_vfs_shutdown ();
 #endif  // WITH_GIO
     }
 
 public:
     static void do_init ()
     {
-        static WorkbenchStaticInit s_wb_init ;
+        static WorkbenchStaticInit s_wb_init;
     }
 
 };//end class WorkbenchStaticInit
 
 class Workbench : public IWorkbench {
-    struct Priv ;
-    SafePtr<Priv> m_priv ;
+    struct Priv;
+    SafePtr<Priv> m_priv;
 
-    Workbench (const Workbench&) ;
-    Workbench& operator= (const Workbench&) ;
+    Workbench (const Workbench&);
+    Workbench& operator= (const Workbench&);
 
 
 private:
@@ -102,72 +102,73 @@ private:
     //************************
     //<slots (signal callbacks)>
     //************************
-    void on_quit_menu_item_action () ;
-    void on_about_menu_item_action () ;
-    void on_contents_menu_item_action () ;
-    void on_shutting_down_signal () ;
+    void on_quit_menu_item_action ();
+    void on_about_menu_item_action ();
+    void on_contents_menu_item_action ();
+    void on_shutting_down_signal ();
     //************************
     //</slots (signal callbacks)>
     //************************
 
-    void init_glade () ;
-    void init_window () ;
-    void init_actions () ;
-    void init_menubar () ;
-    void init_toolbar () ;
-    void init_body () ;
+    void init_builder ();
+    void init_window ();
+    void init_actions ();
+    void init_menubar ();
+    void init_toolbar ();
+    void init_body ();
     void add_perspective_toolbars (IPerspectiveSafePtr &a_perspective,
-                                   list<Gtk::Widget*> &a_tbs) ;
+                                   list<Gtk::Widget*> &a_tbs);
     void add_perspective_body (IPerspectiveSafePtr &a_perspective,
-                               Gtk::Widget *a_body) ;
-    bool remove_perspective_body (IPerspectiveSafePtr &a_perspective) ;
-    void remove_all_perspective_bodies () ;
-    void select_perspective (IPerspectiveSafePtr &a_perspective) ;
+                               Gtk::Widget *a_body);
+    bool remove_perspective_body (IPerspectiveSafePtr &a_perspective);
+    void remove_all_perspective_bodies ();
+    void select_perspective (IPerspectiveSafePtr &a_perspective);
 
-    void save_window_geometry () ;
+    void save_window_geometry ();
 
 
     void do_init ()
     {
         WorkbenchStaticInit::do_init ();
     }
-    bool on_delete_event (GdkEventAny* event) ;
+    bool on_delete_event (GdkEventAny* event);
+    bool query_for_shutdown ();
 
 public:
-    Workbench (DynamicModule *a_dynmod) ;
-    virtual ~Workbench () ;
-    void do_init (Gtk::Main &a_main) ;
-    void shut_down () ;
-    Glib::RefPtr<Gtk::ActionGroup> get_default_action_group () ;
+    Workbench (DynamicModule *a_dynmod);
+    virtual ~Workbench ();
+    void do_init (Gtk::Main &a_main);
+    void shut_down ();
+    Glib::RefPtr<Gtk::ActionGroup> get_default_action_group ();
     Glib::RefPtr<Gtk::ActionGroup> get_debugger_ready_action_group ();
     Gtk::Widget& get_menubar ();
     Gtk::Notebook& get_toolbar_container ();
-    Gtk::Window& get_root_window () ;
-    void set_title_extension (const UString &a_str) ;
-    Glib::RefPtr<Gtk::UIManager>& get_ui_manager ()  ;
-    IPerspective* get_perspective (const UString &a_name) ;
-    IConfMgrSafePtr get_configuration_manager ()  ;
-    Glib::RefPtr<Glib::MainContext> get_main_context ()  ;
-    sigc::signal<void>& shutting_down_signal () ;
+    Gtk::Window& get_root_window ();
+    void set_title_extension (const UString &a_str);
+    Glib::RefPtr<Gtk::UIManager>& get_ui_manager () ;
+    IPerspective* get_perspective (const UString &a_name);
+    IConfMgrSafePtr get_configuration_manager () ;
+    Glib::RefPtr<Glib::MainContext> get_main_context () ;
+    sigc::signal<void>& shutting_down_signal ();
 };//end class Workbench
 
 struct Workbench::Priv {
-    bool initialized ;
-    Gtk::Main *main ;
-    Glib::RefPtr<Gtk::ActionGroup> default_action_group ;
-    Glib::RefPtr<Gtk::UIManager> ui_manager ;
-    Glib::RefPtr<Gnome::Glade::Xml> glade ;
-    SafePtr <Gtk::Window> root_window ;
-    Gtk::Widget *menubar ;
+    bool initialized;
+    Gtk::Main *main;
+    Glib::RefPtr<Gtk::ActionGroup> default_action_group;
+    Glib::RefPtr<Gtk::UIManager> ui_manager;
+    Glib::RefPtr<Gtk::Builder> builder;
+    SafePtr <Gtk::Window> root_window;
+    Gtk::Widget *menubar;
     Gtk::Notebook *toolbar_container;
-    Gtk::Notebook *bodies_container ;
-    PluginManagerSafePtr plugin_manager ;
-    list<IPerspectiveSafePtr> perspectives ;
-    map<IPerspective*, int> toolbars_index_map ;
-    map<IPerspective*, int> bodies_index_map ;
-    map<UString, UString> properties ;
-    IConfMgrSafePtr conf_mgr ;
-    sigc::signal<void> shutting_down_signal ;
+    Gtk::Notebook *bodies_container;
+    PluginManagerSafePtr plugin_manager;
+    list<IPerspectiveSafePtr> perspectives;
+    map<IPerspective*, int> toolbars_index_map;
+    map<IPerspective*, int> bodies_index_map;
+    map<UString, UString> properties;
+    IConfMgrSafePtr conf_mgr;
+    sigc::signal<void> shutting_down_signal;
     UString base_title;
 
     Priv () :
@@ -183,12 +184,28 @@ struct Workbench::Priv {
 };//end Workbench::Priv
 
 #ifndef CHECK_WB_INIT
-#define CHECK_WB_INIT THROW_IF_FAIL(m_priv->initialized) ;
+#define CHECK_WB_INIT THROW_IF_FAIL(m_priv->initialized);
 #endif
 
 //****************
 //private methods
 //****************
+bool
+Workbench::query_for_shutdown ()
+{
+    bool retval = true;
+    list<IPerspectiveSafePtr>::const_iterator iter;
+    for (iter = m_priv->perspectives.begin ();
+         iter != m_priv->perspectives.end ();
+         ++iter) {
+         if ((*iter)->agree_to_shutdown () == false) {
+             retval = false;
+             break;
+         }
+    }
+    return retval;
+}
+
 
 //*********************
 //signal slots methods
@@ -196,7 +213,8 @@ struct Workbench::Priv {
 bool
 Workbench::on_delete_event (GdkEventAny* a_event)
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
+    bool retval = true;
 
     NEMIVER_TRY
     // use event so that compilation doesn't fail with -Werror :(
@@ -204,21 +222,27 @@ Workbench::on_delete_event (GdkEventAny* a_event)
 
     // clicking the window manager's X and shutting down the with Quit menu item
     // should do the same thing
-    on_quit_menu_item_action () ;
+    if (query_for_shutdown () == true) {
+        shut_down ();
+        retval = false;
+    }
+
     NEMIVER_CATCH
 
-    //keep propagating
-    return false;
+    //Will propagate if retval = false, else not
+    return retval;
 }
 
 void
 Workbench::on_quit_menu_item_action ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
     NEMIVER_TRY
 
-    shut_down () ;
+    if (query_for_shutdown () == true) {
+        shut_down ();
+    }
 
     NEMIVER_CATCH
 }
@@ -246,7 +270,7 @@ Workbench::on_contents_menu_item_action ()
 void
 Workbench::on_about_menu_item_action ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
     NEMIVER_TRY
 
@@ -264,7 +288,7 @@ Workbench::on_about_menu_item_action ()
     documenters.push_back ("Jonathon Jongsma <jjongsma@gnome.org>");
     dialog.set_documenters (documenters);
 
-    dialog.set_website ("http://www.gnome.org/projects/nemiver/");
+    dialog.set_website (PACKAGE_URL);
     dialog.set_website_label (_("Project Website"));
 
     Glib::ustring license =
@@ -308,10 +332,10 @@ Workbench::on_about_menu_item_action ()
 void
 Workbench::on_shutting_down_signal ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
     NEMIVER_TRY
-    save_window_geometry () ;
+    save_window_geometry ();
     NEMIVER_CATCH
 }
 
@@ -323,22 +347,22 @@ Workbench::Workbench (DynamicModule *a_dynmod) :
 
 Workbench::~Workbench ()
 {
-    remove_all_perspective_bodies () ;
-    LOG_D ("delete", "destructor-domain") ;
+    remove_all_perspective_bodies ();
+    LOG_D ("delete", "destructor-domain");
 }
 
 void
 Workbench::do_init (Gtk::Main &a_main)
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    DynamicModule::Loader *loader = get_dynamic_module ().get_module_loader () ;
-    THROW_IF_FAIL (loader) ;
+    DynamicModule::Loader *loader = get_dynamic_module ().get_module_loader ();
+    THROW_IF_FAIL (loader);
 
-    DynamicModuleManager *dynmod_manager = loader->get_dynamic_module_manager () ;
-    THROW_IF_FAIL (dynmod_manager) ;
+    DynamicModuleManager *dynmod_manager = loader->get_dynamic_module_manager ();
+    THROW_IF_FAIL (dynmod_manager);
 
-    m_priv->main = &a_main ;
+    m_priv->main = &a_main;
 
     // set the icon that will be used by all workbench windows that don't
     // explicitly call set_icon() (must be set before the root window is
@@ -359,61 +383,61 @@ Workbench::do_init (Gtk::Main &a_main)
         m_priv->root_window->set_default_icon_list(icon_list);
     }
 
-    init_glade () ;
-    init_window () ;
-    init_actions () ;
-    init_menubar () ;
-    init_toolbar () ;
-    init_body () ;
+    init_builder ();
+    init_window ();
+    init_actions ();
+    init_menubar ();
+    init_toolbar ();
+    init_body ();
 
-    m_priv->initialized = true ;
+    m_priv->initialized = true;
 
     m_priv->plugin_manager =
-        PluginManagerSafePtr (new PluginManager (*dynmod_manager)) ;
+        PluginManagerSafePtr (new PluginManager (*dynmod_manager));
 
     NEMIVER_TRY
-        m_priv->plugin_manager->load_plugins () ;
+        m_priv->plugin_manager->load_plugins ();
 
-        map<UString, PluginSafePtr>::const_iterator plugin_iter ;
-        IPerspectiveSafePtr perspective ;
-        Plugin::EntryPointSafePtr entry_point ;
-        list<Gtk::Widget*> toolbars ;
+        map<UString, PluginSafePtr>::const_iterator plugin_iter;
+        IPerspectiveSafePtr perspective;
+        Plugin::EntryPointSafePtr entry_point;
+        list<Gtk::Widget*> toolbars;
 
         //**************************************************************
         //store the list of perspectives we may have loaded as plugins,
         //and init each of them.
         //**************************************************************
-        IWorkbench *workbench = dynamic_cast<IWorkbench*> (this) ;
-        for (plugin_iter = m_priv->plugin_manager->plugins_map ().begin () ;
+        IWorkbench *workbench = dynamic_cast<IWorkbench*> (this);
+        for (plugin_iter = m_priv->plugin_manager->plugins_map ().begin ();
              plugin_iter != m_priv->plugin_manager->plugins_map ().end ();
              ++plugin_iter) {
              LOG_D ("plugin '"
                     << plugin_iter->second->descriptor ()->name ()
                     << "' refcount: "
                     << (int) plugin_iter->second->get_refcount (),
-                    "refcount-domain") ;
+                    "refcount-domain");
             if (plugin_iter->second && plugin_iter->second->entry_point_ptr ()) {
-                entry_point = plugin_iter->second->entry_point_ptr () ;
-                perspective = entry_point.do_dynamic_cast<IPerspective> () ;
+                entry_point = plugin_iter->second->entry_point_ptr ();
+                perspective = entry_point.do_dynamic_cast<IPerspective> ();
                 if (perspective) {
-                    m_priv->perspectives.push_front (perspective) ;
-                    perspective->do_init (workbench) ;
-                    perspective->edit_workbench_menu () ;
-                    toolbars.clear () ;
-                    perspective->get_toolbars (toolbars) ;
-                    add_perspective_toolbars (perspective, toolbars) ;
-                    add_perspective_body (perspective, perspective->get_body ()) ;
+                    m_priv->perspectives.push_front (perspective);
+                    perspective->do_init (workbench);
+                    perspective->edit_workbench_menu ();
+                    toolbars.clear ();
+                    perspective->get_toolbars (toolbars);
+                    add_perspective_toolbars (perspective, toolbars);
+                    add_perspective_body (perspective, perspective->get_body ());
                     LOG_D ("perspective '"
                            << perspective->get_perspective_identifier ()
                            << "' refcount: "
                            << (int) perspective->get_refcount (),
-                           "refcount-domain") ;
+                           "refcount-domain");
                 }
             }
         }
 
         if (!m_priv->perspectives.empty ()) {
-            select_perspective (*m_priv->perspectives.begin ()) ;
+            select_perspective (*m_priv->perspectives.begin ());
         }
     NEMIVER_CATCH
 }
@@ -421,45 +445,45 @@ Workbench::do_init (Gtk::Main &a_main)
 void
 Workbench::shut_down ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    shutting_down_signal ().emit () ;
-    m_priv->main->quit () ;
+    shutting_down_signal ().emit ();
+    m_priv->main->quit ();
 }
 
 Glib::RefPtr<Gtk::ActionGroup>
 Workbench::get_default_action_group ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    CHECK_WB_INIT ;
-    THROW_IF_FAIL (m_priv) ;
-    return m_priv->default_action_group ;
+    CHECK_WB_INIT;
+    THROW_IF_FAIL (m_priv);
+    return m_priv->default_action_group;
 }
 
 Gtk::Widget&
 Workbench::get_menubar ()
 {
-    CHECK_WB_INIT ;
-    THROW_IF_FAIL (m_priv && m_priv->menubar) ;
-    return *m_priv->menubar ;
+    CHECK_WB_INIT;
+    THROW_IF_FAIL (m_priv && m_priv->menubar);
+    return *m_priv->menubar;
 }
 
 Gtk::Notebook&
 Workbench::get_toolbar_container ()
 {
-    CHECK_WB_INIT ;
-    THROW_IF_FAIL (m_priv && m_priv->toolbar_container) ;
-    return *m_priv->toolbar_container ;
+    CHECK_WB_INIT;
+    THROW_IF_FAIL (m_priv && m_priv->toolbar_container);
+    return *m_priv->toolbar_container;
 }
 
 Gtk::Window&
 Workbench::get_root_window ()
 {
-    CHECK_WB_INIT ;
-    THROW_IF_FAIL (m_priv && m_priv->root_window) ;
+    CHECK_WB_INIT;
+    THROW_IF_FAIL (m_priv && m_priv->root_window);
 
-    return *m_priv->root_window ;
+    return *m_priv->root_window;
 }
 
 void
@@ -475,91 +499,91 @@ Workbench::set_title_extension (const UString &a_str)
 Glib::RefPtr<Gtk::UIManager>&
 Workbench::get_ui_manager ()
 {
-    THROW_IF_FAIL (m_priv) ;
+    THROW_IF_FAIL (m_priv);
     if (!m_priv->ui_manager) {
-        m_priv->ui_manager = Gtk::UIManager::create () ;
-        THROW_IF_FAIL (m_priv->ui_manager) ;
+        m_priv->ui_manager = Gtk::UIManager::create ();
+        THROW_IF_FAIL (m_priv->ui_manager);
     }
-    return m_priv->ui_manager ;
+    return m_priv->ui_manager;
 }
 
 IPerspective*
 Workbench::get_perspective (const UString &a_name)
 {
-    list<IPerspectiveSafePtr>::const_iterator iter ;
+    list<IPerspectiveSafePtr>::const_iterator iter;
     for (iter = m_priv->perspectives.begin ();
          iter != m_priv->perspectives.end ();
          ++iter) {
         if ((*iter)->descriptor ()->name () == a_name) {
-            return iter->get () ;
+            return iter->get ();
         }
     }
-    LOG_ERROR ("could not find perspective: '" << a_name << "'") ;
+    LOG_ERROR ("could not find perspective: '" << a_name << "'");
     return NULL;
 }
 
 IConfMgrSafePtr
 Workbench::get_configuration_manager ()
 {
-    THROW_IF_FAIL (m_priv) ;
+    THROW_IF_FAIL (m_priv);
     if (!m_priv->conf_mgr) {
         DynamicModule::Loader *loader =
-            get_dynamic_module ().get_module_loader () ;
-        THROW_IF_FAIL (loader) ;
+            get_dynamic_module ().get_module_loader ();
+        THROW_IF_FAIL (loader);
 
         DynamicModuleManager *dynmod_manager =
-                loader->get_dynamic_module_manager () ;
-        THROW_IF_FAIL (dynmod_manager) ;
+                loader->get_dynamic_module_manager ();
+        THROW_IF_FAIL (dynmod_manager);
 
         m_priv->conf_mgr = dynmod_manager->load_iface <IConfMgr> ("gconfmgr",
-                                                                  "IConfMgr") ;
+                                                                  "IConfMgr");
         NEMIVER_TRY
 
-        m_priv->conf_mgr->set_key_dir_to_notify ("/apps/nemiver") ;
+        m_priv->conf_mgr->set_key_dir_to_notify ("/apps/nemiver");
         m_priv->conf_mgr->add_key_to_notify (
-                "/desktop/gnome/interface/monospace_font_name") ;
+                "/desktop/gnome/interface/monospace_font_name");
 
         NEMIVER_CATCH_NOX
     }
-    THROW_IF_FAIL (m_priv->conf_mgr) ;
-    return m_priv->conf_mgr ;
+    THROW_IF_FAIL (m_priv->conf_mgr);
+    return m_priv->conf_mgr;
 }
 
 Glib::RefPtr<Glib::MainContext>
 Workbench::get_main_context ()
 {
-    THROW_IF_FAIL (m_priv) ;
-    return Glib::MainContext::get_default () ;
+    THROW_IF_FAIL (m_priv);
+    return Glib::MainContext::get_default ();
 }
 
 sigc::signal<void>&
 Workbench::shutting_down_signal ()
 {
-    THROW_IF_FAIL (m_priv) ;
+    THROW_IF_FAIL (m_priv);
 
-    return m_priv->shutting_down_signal ;
+    return m_priv->shutting_down_signal;
 }
 
 void
-Workbench::init_glade ()
+Workbench::init_builder ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    THROW_IF_FAIL (m_priv) ;
+    THROW_IF_FAIL (m_priv);
 
-    UString file_path = env::build_path_to_glade_file ("workbench.glade") ;
-    m_priv->glade = Gnome::Glade::Xml::create (file_path) ;
-    THROW_IF_FAIL (m_priv->glade) ;
+    UString file_path = env::build_path_to_gtkbuilder_file ("workbench.ui");
+    m_priv->builder = Gtk::Builder::create_from_file (file_path);
+    THROW_IF_FAIL (m_priv->builder);
 
     Gtk::Widget *w =
-        ui_utils::get_widget_from_glade<Gtk::Window> (m_priv->glade,
+        ui_utils::get_widget_from_gtkbuilder<Gtk::Window> (m_priv->builder,
                                                       "workbench");
     THROW_IF_FAIL (w);
     m_priv->root_window.reset (dynamic_cast<Gtk::Window*>
                                                 (w->get_toplevel ()));
     THROW_IF_FAIL (m_priv->root_window);
     //get the title of the toplevel window as specified in the
-    //glade file and save
+    //gtkbuilder file and save
     //it so that later we can add state-specific
     //extensions to this base title
     //if needed
@@ -569,45 +593,45 @@ void
 
 Workbench::init_window ()
 {
-   LOG_FUNCTION_SCOPE_NORMAL_DD ;
+   LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    THROW_IF_FAIL (m_priv) ;
-    THROW_IF_FAIL (m_priv->root_window) ;
-    IConfMgrSafePtr conf_mgr = get_configuration_manager () ;
-    THROW_IF_FAIL (conf_mgr) ;
+    THROW_IF_FAIL (m_priv);
+    THROW_IF_FAIL (m_priv->root_window);
+    IConfMgrSafePtr conf_mgr = get_configuration_manager ();
+    THROW_IF_FAIL (conf_mgr);
 
-    int width=700, height=500, pos_x=0, pos_y=0 ;
-    bool maximized=false ;
+    int width=700, height=500, pos_x=0, pos_y=0;
+    bool maximized=false;
 
-    LOG_DD ("getting windows geometry from confmgr ...") ;
+    LOG_DD ("getting windows geometry from confmgr ...");
 
     NEMIVER_TRY
-    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width) ;
-    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height) ;
-    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x) ;
-    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y) ;
-    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized) ;
-    LOG_DD ("got windows geometry from confmgr.") ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width);
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height);
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x);
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y);
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized);
+    LOG_DD ("got windows geometry from confmgr.");
     NEMIVER_CATCH_NOX
 
     if (width) {
-        LOG_DD ("restoring windows geometry from confmgr ...") ;
-        m_priv->root_window->resize (width, height) ;
-        m_priv->root_window->move (pos_x, pos_y) ;
+        LOG_DD ("restoring windows geometry from confmgr ...");
+        m_priv->root_window->resize (width, height);
+        m_priv->root_window->move (pos_x, pos_y);
         if (maximized) {
-            m_priv->root_window->maximize () ;
+            m_priv->root_window->maximize ();
         }
-        LOG_DD ("restored windows geometry from confmgr") ;
+        LOG_DD ("restored windows geometry from confmgr");
     } else {
-        LOG_DD ("null window geometry from confmgr.") ;
+        LOG_DD ("null window geometry from confmgr.");
     }
 
     //set the minimum width/height of nemiver, just in case.
-    width=0, height=0 ;
+    width=0, height=0;
 
     NEMIVER_TRY
-    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_WIDTH, width) ;
-    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_HEIGHT, height) ;
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_WIDTH, width);
+    conf_mgr->get_key_value (CONF_KEY_NEMIVER_WINDOW_MINIMUM_HEIGHT, height);
     NEMIVER_CATCH
 
     if (!width)
@@ -615,15 +639,15 @@ Workbench::init_window ()
     if (!height)
         height = 500;
 
-    m_priv->root_window->set_size_request (width, height) ;
+    m_priv->root_window->set_size_request (width, height);
     LOG_DD ("set windows min size to ("
             << (int) width
             << ","
             << (int) height
-            << ")") ;
+            << ")");
 
     shutting_down_signal ().connect (sigc::mem_fun
-                        (*this, &Workbench::on_shutting_down_signal)) ;
+                        (*this, &Workbench::on_shutting_down_signal));
     m_priv->root_window->signal_delete_event ().connect (
             sigc::mem_fun (*this, &Workbench::on_delete_event));
 }
@@ -631,11 +655,11 @@ Workbench::init_window ()
 void
 Workbench::init_actions ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    Gtk::StockID nil_stock_id ("") ;
-    sigc::slot<void> nil_slot ;
-    using ui_utils::ActionEntry ;
+    Gtk::StockID nil_stock_id ("");
+    sigc::slot<void> nil_slot;
+    using ui_utils::ActionEntry;
 
     static ActionEntry s_default_action_entries [] = {
         {
@@ -706,81 +730,81 @@ Workbench::init_actions ()
     };
 
     m_priv->default_action_group =
-        Gtk::ActionGroup::create ("workbench-default-action-group") ;
+        Gtk::ActionGroup::create ("workbench-default-action-group");
     int num_default_actions =
-         sizeof (s_default_action_entries)/sizeof (ui_utils::ActionEntry) ;
+         sizeof (s_default_action_entries)/sizeof (ui_utils::ActionEntry);
     ui_utils::add_action_entries_to_action_group (s_default_action_entries,
                                                   num_default_actions,
-                                                  m_priv->default_action_group) ;
-    get_ui_manager ()->insert_action_group (m_priv->default_action_group) ;
+                                                  m_priv->default_action_group);
+    get_ui_manager ()->insert_action_group (m_priv->default_action_group);
 }
 
 void
 Workbench::init_menubar ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    THROW_IF_FAIL (m_priv && m_priv->default_action_group) ;
+    THROW_IF_FAIL (m_priv && m_priv->default_action_group);
 
 
-    UString file_path = env::build_path_to_menu_file ("menubar.xml") ;
-    m_priv->ui_manager->add_ui_from_file (file_path) ;
+    UString file_path = env::build_path_to_menu_file ("menubar.xml");
+    m_priv->ui_manager->add_ui_from_file (file_path);
 
-    m_priv->menubar = m_priv->ui_manager->get_widget ("/MenuBar") ;
-    THROW_IF_FAIL (m_priv->menubar) ;
+    m_priv->menubar = m_priv->ui_manager->get_widget ("/MenuBar");
+    THROW_IF_FAIL (m_priv->menubar);
 
     Gtk::Box *menu_container =
-        ui_utils::get_widget_from_glade<Gtk::Box> (m_priv->glade, "menucontainer");
-    menu_container->pack_start (*m_priv->menubar) ;
-    menu_container->show_all () ;
+        ui_utils::get_widget_from_gtkbuilder<Gtk::Box> (m_priv->builder, "menucontainer");
+    menu_container->pack_start (*m_priv->menubar);
+    menu_container->show_all ();
 }
 
 void
 Workbench::init_toolbar ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
     m_priv->toolbar_container =
-        ui_utils::get_widget_from_glade<Gtk::Notebook> (m_priv->glade,
-                                                        "toolbarcontainer") ;
+        ui_utils::get_widget_from_gtkbuilder<Gtk::Notebook> (m_priv->builder,
+                                                        "toolbarcontainer");
 }
 
 void
 Workbench::init_body ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
     m_priv->bodies_container =
-        ui_utils::get_widget_from_glade<Gtk::Notebook> (m_priv->glade,
-                                                        "bodynotebook") ;
+        ui_utils::get_widget_from_gtkbuilder<Gtk::Notebook> (m_priv->builder,
+                                                        "bodynotebook");
 }
 
 void
 Workbench::add_perspective_toolbars (IPerspectiveSafePtr &a_perspective,
                                      list<Gtk::Widget*> &a_tbs)
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    if (a_tbs.empty ()) {return ;}
+    if (a_tbs.empty ()) {return;}
 
-    SafePtr<Gtk::Box> box (Gtk::manage (new Gtk::VBox)) ;
-    list<Gtk::Widget*>::const_iterator iter ;
+    SafePtr<Gtk::Box> box (Gtk::manage (new Gtk::VBox));
+    list<Gtk::Widget*>::const_iterator iter;
 
-    for (iter = a_tbs.begin (); iter != a_tbs.end () ; ++iter) {
-        box->pack_start (**iter) ;
+    for (iter = a_tbs.begin (); iter != a_tbs.end (); ++iter) {
+        box->pack_start (**iter);
     }
 
-    box->show_all () ;
+    box->show_all ();
     m_priv->toolbars_index_map [a_perspective.get ()] =
-                    m_priv->toolbar_container->insert_page (*box, -1) ;
+                    m_priv->toolbar_container->insert_page (*box, -1);
 
-    box.release () ;
+    box.release ();
 }
 
 void
 Workbench::add_perspective_body (IPerspectiveSafePtr &a_perspective,
                                  Gtk::Widget *a_body)
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
     if (!a_body || !a_perspective) {return;}
 
@@ -791,51 +815,51 @@ Workbench::add_perspective_body (IPerspectiveSafePtr &a_perspective,
 bool
 Workbench::remove_perspective_body (IPerspectiveSafePtr &a_perspective)
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    THROW_IF_FAIL (m_priv) ;
-    THROW_IF_FAIL (m_priv->bodies_container) ;
+    THROW_IF_FAIL (m_priv);
+    THROW_IF_FAIL (m_priv->bodies_container);
 
     if (!a_perspective) {return false;}
 
     map<IPerspective*, int>::iterator it;
-    it = m_priv->bodies_index_map.find (a_perspective.get ()) ;
+    it = m_priv->bodies_index_map.find (a_perspective.get ());
     if (it == m_priv->bodies_index_map.end ()) {
-        return false ;
+        return false;
     }
-    m_priv->bodies_container->remove_page (it->second)  ;
-    m_priv->bodies_index_map.erase (it) ;
-    return true ;
+    m_priv->bodies_container->remove_page (it->second) ;
+    m_priv->bodies_index_map.erase (it);
+    return true;
 }
 
 void
 Workbench::save_window_geometry () 
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    THROW_IF_FAIL (m_priv) ;
-    THROW_IF_FAIL (m_priv->root_window) ;
-    IConfMgrSafePtr conf_mgr = get_configuration_manager () ;
-    THROW_IF_FAIL (conf_mgr) ;
+    THROW_IF_FAIL (m_priv);
+    THROW_IF_FAIL (m_priv->root_window);
+    IConfMgrSafePtr conf_mgr = get_configuration_manager ();
+    THROW_IF_FAIL (conf_mgr);
 
-    int width=0, height=0, pos_x=0, pos_y=0 ;
-    m_priv->root_window->get_size (width, height) ;
-    m_priv->root_window->get_position (pos_x, pos_y) ;
+    int width=0, height=0, pos_x=0, pos_y=0;
+    m_priv->root_window->get_size (width, height);
+    m_priv->root_window->get_position (pos_x, pos_y);
     bool maximized = (m_priv->root_window->get_window()->get_state()
                       & Gdk::WINDOW_STATE_MAXIMIZED);
 
     NEMIVER_TRY
-    conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized) ;
+    conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_MAXIMIZED, maximized);
 
     if (!maximized) {
-        LOG_DD ("storing windows geometry to confmgr...") ;
-        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width) ;
-        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height) ;
-        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x) ;
-        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y) ;
-        LOG_DD ("windows geometry stored to confmgr") ;
+        LOG_DD ("storing windows geometry to confmgr...");
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_WIDTH, width);
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_HEIGHT, height);
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_X, pos_x);
+        conf_mgr->set_key_value (CONF_KEY_NEMIVER_WINDOW_POSITION_Y, pos_y);
+        LOG_DD ("windows geometry stored to confmgr");
     } else {
-        LOG_DD ("windows was maximized, didn't store its geometry") ;
+        LOG_DD ("windows was maximized, didn't store its geometry");
     }
     NEMIVER_CATCH_NOX
 }
@@ -843,44 +867,44 @@ Workbench::save_window_geometry ()
 void
 Workbench::remove_all_perspective_bodies ()
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    map<IPerspective*, int>::iterator it ;
+    map<IPerspective*, int>::iterator it;
     for (it = m_priv->bodies_index_map.begin ();
          it != m_priv->bodies_index_map.end ();
          ++it) {
-        m_priv->bodies_container->remove_page (it->second) ;
+        m_priv->bodies_container->remove_page (it->second);
     }
-    m_priv->bodies_index_map.clear () ;
+    m_priv->bodies_index_map.clear ();
 }
 
 void
 Workbench::select_perspective (IPerspectiveSafePtr &a_perspective)
 {
-    LOG_FUNCTION_SCOPE_NORMAL_DD ;
+    LOG_FUNCTION_SCOPE_NORMAL_DD;
 
-    THROW_IF_FAIL (m_priv) ;
-    THROW_IF_FAIL (m_priv->toolbar_container) ;
-    THROW_IF_FAIL (m_priv->bodies_container) ;
+    THROW_IF_FAIL (m_priv);
+    THROW_IF_FAIL (m_priv->toolbar_container);
+    THROW_IF_FAIL (m_priv->bodies_container);
 
-    map<IPerspective*, int>::const_iterator iter, nil ;
-    int toolbar_index=0, body_index=0 ;
+    map<IPerspective*, int>::const_iterator iter, nil;
+    int toolbar_index=0, body_index=0;
 
-    nil = m_priv->toolbars_index_map.end () ;
-    iter = m_priv->toolbars_index_map.find (a_perspective.get ()) ;
+    nil = m_priv->toolbars_index_map.end ();
+    iter = m_priv->toolbars_index_map.find (a_perspective.get ());
     if (iter != nil) {
-        toolbar_index = iter->second ;
+        toolbar_index = iter->second;
     }
 
-    nil = m_priv->bodies_index_map.end () ;
-    iter = m_priv->bodies_index_map.find (a_perspective.get ()) ;
+    nil = m_priv->bodies_index_map.end ();
+    iter = m_priv->bodies_index_map.find (a_perspective.get ());
     if (iter != nil) {
-        body_index = iter->second ;
+        body_index = iter->second;
     }
 
-    m_priv->toolbar_container->set_current_page (toolbar_index) ;
+    m_priv->toolbar_container->set_current_page (toolbar_index);
 
-    m_priv->bodies_container->set_current_page (body_index) ;
+    m_priv->bodies_container->set_current_page (body_index);
 }
 
 class WorkbenchModule : public DynamicModule {
@@ -895,19 +919,19 @@ public:
     {
         static Info s_info ("workbench",
                             "The workbench of Nemiver",
-                            "1.0") ;
-        a_info = s_info ;
+                            "1.0");
+        a_info = s_info;
     }
 
     bool lookup_interface (const std::string &a_iface_name,
                            DynModIfaceSafePtr &a_iface)
     {
         if (a_iface_name == "IWorkbench") {
-            a_iface.reset (new Workbench (this)) ;
+            a_iface.reset (new Workbench (this));
         } else {
-            return false ;
+            return false;
         }
-        return true ;
+        return true;
     }
 };//end class WorkbenchModule
 
@@ -919,7 +943,7 @@ bool
 NEMIVER_API nemiver_common_create_dynamic_module_instance (void **a_new_instance)
 {
     *a_new_instance = new nemiver::WorkbenchModule ();
-    return (*a_new_instance != 0) ;
+    return (*a_new_instance != 0);
 }
 
 }//end extern C
